OC.L10N.register(
    "firstrunwizard",
    {
    "Privacy" : "Vie privée",
    "Community" : "Tamezdagnut",
    "About" : "Γef",
    "Copy link" : "Nɣel aseɣwen",
    "Copied!" : "Yenɣel!",
    "Not supported!" : "Ur yettusefrak ara!",
    "Press ⌘-C to copy." : "Senned ɣef ⌘-C akken ad tneɣleḍ.",
    "Press Ctrl-C to copy." : "Senned ɣef Ctrl-C akken ad tneɣleḍ."
},
"nplurals=2; plural=(n != 1);");
